/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "nspluginroot.idl"

%{C++
#include "nsplugindefs.h"

#define MOZ_PLUGIN_CONTRACTID \
  "@mozilla.org/plugin/plugin;1"
%}

interface nsIPluginInstance;

[uuid(0937FB08-16E8-4365-BABF-88E09E4E33A4)]
interface nsIPlugin : nsISupports
{
  /**
   * Creates a new plugin instance, based on a MIME type. This
   * allows different impelementations to be created depending on
   * the specified MIME type.
   */
  void createPluginInstance(out nsIPluginInstance aResult);

  /**
   * Initializes the plugin and will be called before any new instances are
   * created. It is passed browserInterfaces on which QueryInterface
   * may be used to obtain an nsIPluginManager, and other interfaces.
   *
   * @param browserInterfaces - an object that allows access to other browser
   * interfaces via QueryInterface
   * @result - NS_OK if this operation was successful
   */
  void initialize();

  /**
   * Called when the browser is done with the plugin factory, or when
   * the plugin is disabled by the user.
   *
   * (Corresponds to NPP_Shutdown.)
   *
   * @result - NS_OK if this operation was successful
   */
  void shutdown();

  /**
   * Returns the MIME description for the plugin. The MIME description 
   * is a colon-separated string containg the plugin MIME type, plugin
   * data file extension, and plugin name, e.g.:
   *
   * "application/x-simple-plugin:smp:Simple Sample Plug-in"
   *
   * (Corresponds to NPP_GetMIMEDescription.)
   *
   * @param aMIMEDescription - the resulting MIME description 
   * @result                 - NS_OK if this operation was successful
   */
  void getMIMEDescription(out constCharPtr aMIMEDescription);

  /**
   * Returns the value of a variable associated with the plugin.
   *
   * (Corresponds to NPP_GetValue.)
   *
   * @param aVariable - the plugin variable to get
   * @param aValue    - the address of where to store the resulting value
   * @result          - NS_OK if this operation was successful
   */
  void getValue(in nsPluginVariable aVariable, in voidPtr aValue);
};
